====================
Module: pyhasse.core
====================

* Free software: MIT license
* Documentation: https://pyhasse.org

Features
--------

Basic module for all pyhasse modules:

- import data from csv files

Display parts of the dataset after import:

- Attributes
- Objects
- Data

Calculate:

- Zeta matrix
- Cover matrix
- Levels
- Equivalence classes
- Distances
